SwissFit objects
================

.. autoclass:: swissfit.SwissFit(data=None,udata=None,prior=None,uprior=None,p0=None,fit_fcn=None,prior_fcn=None,prior_transformation_fcn={},data_svdcut=None,prior_svdcut=None)